Package: mlr3tuningspaces
Title: Search Spaces for 'mlr3'
Version: 0.7.0
Authors@R: c(
    person("Marc", "Becker", , "marcbecker@posteo.de", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-8115-0400")),
    person("Michel", "Lang", , "michellang@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-9754-0393"))
  )
Description: Collection of search spaces for hyperparameter optimization in the
  'mlr3' ecosystem. It features ready-to-use search spaces for many popular
  machine learning algorithms. The search spaces are from scientific articles
  and work for a wide range of data sets.
License: LGPL-3
URL: https://mlr3tuningspaces.mlr-org.com,
        https://github.com/mlr-org/mlr3tuningspaces
BugReports: https://github.com/mlr-org/mlr3tuningspaces/issues
Depends: mlr3tuning (>= 0.15.0), R (>= 3.1.0)
Imports: cli, checkmate (>= 2.0.0), data.table (>= 1.14.0), mlr3 (>=
        0.11.0), mlr3misc (>= 0.11.0), paradox (>= 0.7.1), R6 (>=
        2.5.0)
Suggests: e1071 (>= 1.7-6), bbotk, glmnet (>= 4.1-2), mlr3learners (>=
        0.4.5), mlr3pipelines, ranger (>= 0.12.1), rpart (>= 4.1-15),
        testthat (>= 3.0.0), xgboost (>= 1.4.1.1), torch (>= 0.15.0),
        mlr3torch (>= 0.3)
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
Collate: 'mlr_tuning_spaces.R' 'TuningSpace.R' 'bibentries.R' 'sugar.R'
        'tuning_spaces_default.R' 'tuning_spaces_rbv1.R'
        'tuning_spaces_rbv2.R' 'tuning_spaces_rtdl.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2026-07-25 11:19:19 UTC; marc
Author: Marc Becker [cre, aut] (ORCID: <https://orcid.org/0000-0002-8115-0400>),
  Michel Lang [ctb] (ORCID: <https://orcid.org/0000-0001-9754-0393>)
Maintainer: Marc Becker <marcbecker@posteo.de>
Repository: CRAN
Date/Publication: 2026-07-25 11:50:02 UTC
