# Generated by roxygen2: do not edit by hand

S3method(as.data.table,DictionaryTuningSpaces)
S3method(as.data.table,TuningSpace)
S3method(as_search_space,TuningSpace)
S3method(lts,Learner)
S3method(lts,character)
S3method(lts,missing)
S3method(rd_info,TuningSpace)
export(TuningSpace)
export(lts)
export(ltss)
export(mlr_tuning_spaces)
import(checkmate)
import(cli)
import(data.table)
import(mlr3)
import(mlr3misc)
import(mlr3tuning)
import(paradox)
importFrom(R6,R6Class)
importFrom(utils,bibentry)
